.. parcels documentation master file, created by
   sphinx-quickstart on Tue Oct 20 09:58:20 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Parcels documentation
===================================

Welcome to the documentation of parcels. This page provides detailed documentation for each method, class and function.
The documentation corresponds to the latest conda release, for newer documentation see the docstrings in the code.

See http://www.oceanparcels.org for general information on the Parcels project, including how to install and use.

parcels.particleset module
--------------------------

.. automodule:: parcels.particleset.particlesetsoa
    :members:
    :show-inheritance:

parcels.fieldset module
-----------------------

.. automodule:: parcels.fieldset
    :members:
    :show-inheritance:

parcels.field module
--------------------

.. automodule:: parcels.field
    :members:
    :show-inheritance:

parcels.gridset module
----------------------

.. automodule:: parcels.gridset
    :members:
    :show-inheritance:

parcels.grid module
-------------------

.. automodule:: parcels.grid
    :members:
    :show-inheritance:

parcels.particle module
-----------------------

.. automodule:: parcels.particle
    :members:
    :show-inheritance:

parcels.application_kernels.advection module
--------------------------------------------

.. automodule:: parcels.application_kernels.advection
    :members:
    :show-inheritance:

parcels.application_kernels.advectiondiffusion module
-----------------------------------------------------


.. automodule:: parcels.application_kernels.advectiondiffusion
    :members:
    :show-inheritance:

parcels.application_kernels.EOSseawaterproperties module
--------------------------------------------------------


.. automodule:: parcels.application_kernels.EOSseawaterproperties
    :members:
    :show-inheritance:

parcels.application_kernels.TEOSseawaterdensity module
------------------------------------------------------


.. automodule:: parcels.application_kernels.TEOSseawaterdensity
    :members:
    :show-inheritance:

parcels.compilation module
--------------------------

.. automodule:: parcels.compilation
    :members:
    :show-inheritance: yes

parcels.interaction module
--------------------------

.. automodule:: parcels.interaction
    :members:
    :show-inheritance: yes

parcels.interaction.neighborsearch module
-----------------------------------------

.. automodule:: parcels.interaction.neighborsearch
    :members:
    :show-inheritance: yes

parcels.kernel.basekernel module
--------------------------------

.. automodule:: parcels.kernel.basekernel
    :members:
    :undoc-members:

parcels.kernel.kernelaos module
-------------------------------

.. automodule:: parcels.kernel.kernelaos
    :members:
    :undoc-members:

parcels.kernel.kernelsoa module
-------------------------------

.. automodule:: parcels.kernel.kernelsoa
    :members:
    :undoc-members:

parcels.particlefile.baseparticlefile module
--------------------------------------------

.. automodule:: parcels.particlefile.baseparticlefile
    :members:
    :show-inheritance: yes

parcels.particlefile.particlefileaos module
-------------------------------------------

.. automodule:: parcels.particlefile.particlefileaos
    :members:
    :show-inheritance: yes

parcels.particlefile.particlefilesoa module
-------------------------------------------

.. automodule:: parcels.particlefile.particlefilesoa
    :members:
    :show-inheritance: yes

parcels.rng module
------------------

.. automodule:: parcels.rng
    :members:
    :undoc-members:

parcels.particleset.baseparticleset module
-------------------------------------------

.. automodule:: parcels.particleset.baseparticleset
    :members:
    :show-inheritance:

parcels.particleset.particlesetaos module
-----------------------------------------

.. automodule:: parcels.particleset.particlesetaos
    :members:
    :show-inheritance:

parcels.tools.statuscodes module
--------------------------------

.. automodule:: parcels.tools.statuscodes
    :members:
    :show-inheritance:

parcels.tools.converters module
-------------------------------

.. automodule:: parcels.tools.converters
    :members:
    :show-inheritance:

parcels.tools.loggers module
----------------------------

.. automodule:: parcels.tools.loggers
    :members:
    :undoc-members:

parcels.plotting module
-----------------------

.. automodule:: parcels.plotting
    :members:
    :undoc-members:

scripts.plottrajectoriesfile module
-----------------------------------

.. automodule:: scripts.plottrajectoriesfile
    :members:
    :undoc-members:

scripts.get_examples module
---------------------------

.. automodule:: scripts.get_examples
    :members:
    :undoc-members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
